# mdutil

`mdutil` is a Python cli application designed to help with common tasks in the context of game development for retro systems. It's specially tailored but not limited to the Sega Megadrive used in conjuntion
with [SGDK](https://github.com/Stephane-D/SGDK).

## Requirements

- Python 3.8+
- pipx

## Installation

Make sure to install the requirements. A complete guide on how to install `pipx` can be found at [link](https://pipx.pypa.io/stable/installation).

After that, open a terminal and run the following command:

```bash
pipx install mdutilities
```

This will install `mdutil` in a virtual environment managed by `pipx`. You can now start using it from the command line. Check the currently installed version by running:

```bash
mdutil version
```

When a new version becomes available you can upgrade your local installation by running:

```bash
pipx upgrade mdutilities
```

To completely uninstall `mdutil` run:

```bash
pipx uninstall mdutilities
```

## Usage

The full user guide can be found at [read the docs](https://mdutil.readthedocs.io).

## License

This project is licensed under the MIT License. See the LICENSE file for details.

## Contributing

Contributions are welcome! please open an issue or submit a pull request for any improvements or
bug fixes.

## Contact

For any questions or suggestions, please open an issue on GitHub.